#!/usr/bin/perl -w
#=========================================================================
#
#    AddPricing.pl
#
#    Read a simple Excel list containing journal pricings and add them
#    to the database.
#
#    $Id: $
#    Last change: <Tue, 2009/01/06 18:19:43 arwagner ingata>
#    Author     : Alexander Wagner
#    Language   : Perl
#
#-------------------------------------------------------------------------
#
#    Copyright (C) 2008 by Alexander Wagner
#
#    This is free software; you can redistribute it and/or modify it
#    under the terms of the GNU Genereal Public License as published
#    by the Free Software Foundation; either version 2, or (at your
#    option) any later version.
#
#    This program is distributed in the hope that it will be usefull,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#    General Public License for more details.
#
#    You should have recieved a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#=========================================================================

# input is xls, output is mysql, some data comes from ZDB
use Spreadsheet::ParseExcel;
use IO::Handle;
use EZeit;
*STDOUT->autoflush(1);    # Unbuffered screen IO

#======================================================================
my $Excelj1        = new Spreadsheet::ParseExcel;
my $Sheet          = 0;
my $Bookj1;
my $XLSFile        = "Preisliste.xls";

EZeit::ReadConfig();
$dbh = EZeit::ConnectDB();

if (-e "$XLSFile") {
   $Bookj1   = $Excelj1->Parse("$XLSFile");

   my $Wksj1    = $Bookj1->{Worksheet}[$Sheet];

   for(my $Row = 1 ;
   defined $Wksj1->{MaxRow} && $Row <= $Wksj1->{MaxRow};
   $Row++) {
      $subsid = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}]->Value;
      $year   = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+4]->Value;

      # use ->{Val}: get the bare numerical value unformated ie. a
      # real number with decent puctuation
      $price  = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+5]->{Val};

      # seems to be stored internally as number with a , as thousands
      # speparator
      $price =~ s/,//g;

      $sql  = "INSERT INTO Jsubsprice (subsid, year, price) ";
      $sql .= "VALUES ($subsid, $year, $price);";
      print "$sql\n";

      EZeit::ExecuteSQL($dbh, $sql);
   }

}
else {
   print "$XLSFile does not exist!\n";
   print "Exiting...\n\n";
}

$dbh->disconnect();

