#!/usr/bin/perl -w
#=========================================================================
#
#    D1-Reader.pl
#
#    Read in Counter D1 files and store them an the database.
#
#    $Id: $
#    Last change: <Tue, 2009/01/06 18:20:48 arwagner ingata>
#    Author     : Alexander Wagner
#    Language   : Perl
#
#-------------------------------------------------------------------------
#
#    Copyright (C) 2008 by Alexander Wagner
#
#    This is free software; you can redistribute it and/or modify it
#    under the terms of the GNU Genereal Public License as published
#    by the Free Software Foundation; either version 2, or (at your
#    option) any later version.
#
#    This program is distributed in the hope that it will be usefull,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#    General Public License for more details.
#
#    You should have recieved a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#=========================================================================

# input is xls, output is mysql, some data comes from ZDB
use Spreadsheet::ParseExcel;
use DBI;
use IO::Handle;
use EZeit;
*STDOUT->autoflush(1);    # Unbuffered screen IO

#======================================================================
my $Excelj1        = new Spreadsheet::ParseExcel;
my $Sheet          = 0;
my $Bookj1;

EZeit::ReadConfig();
$dbh = EZeit::ConnectDB();

print <<EOF
Process indicators:
     .    For each dataset
     m    monthly usage ....... ADD/UPDATE
     y    yearly usage ........ UPDATE
     Y    ..................... ADD

      Markers printed: $EZeit::markerstring

EOF
;

print "Input     : $EZeit::inputdir\n\n";

foreach $year (@EZeit::years) {
   foreach $d1prefix (@EZeit::d1files) {

      my $dbd1file = "$d1prefix$year.xls";

      # Search the counter statistics
      if (-e "$EZeit::inputdir/$dbd1file") {
         $Bookj1   = $Excelj1->Parse("$EZeit::inputdir/$dbd1file");
      }
      else {
         print "$EZeit::inputdir/$dbd1file does not exist!\n";
         print "Exiting...\n\n";
         next;
      }

      my $Wksj1    = $Bookj1->{Worksheet}[$Sheet];

      print "\n\n"; 
      print "Year      : $year\n"; 
      print "Statistics: $dbd1file, ", $Wksj1->{MaxRow}-5 , " datasets\n"; 
      print "Database  : $EZeit::dbname\@$EZeit::dbhost\n\n";

      for(my $Row = 5 ;
      defined $Wksj1->{MaxRow} && $Row <= $Wksj1->{MaxRow};
      $Row++) {
         my $database  = ""; my $publisher = "";
         my $platform  = ""; my $action    = "";
         my @usage     = (); my $YTD       = 0;

         Marker(".");

         # None delivers real D1, at least publisher seems to lack
         # everywhere in the reports
         if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}])) {
            $database   = EZeit::trim($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}]->Value);
         }

         if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+1])) {
            $platform   = EZeit::trim($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+1]->Value);
         }
         if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+2])) {
            $action     = EZeit::trim($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+2]->Value);
         }

         # Here the monthly values should be read in. It can be between 0
         # and 12 columns for the months.
         # Guess: it starts in january. The headings are of no help.
         for (my $i=3; $i < $Wksj1->{MaxCol}; $i++) {
            if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+$i])) {
               $usage[$i-3] = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+$i]->{Val};

            }
            else {
               $usage[$i-3] = 0;
            }
         }

         # The yearly data has to be there
         if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MaxCol}])) {
            $YTD = $Wksj1->{Cells}[$Row][$Wksj1->{MaxCol}]->{Val};
         }

         if (length($database) > 0) {
            $subsid = EZeit::GetDBsubsid($dbh, $database, $platform);

            # print "   ", EZeit::GetDBsubsid($dbh, $database, $platform), "\n";
            
            if ($action =~ m/Searches/) {
               EZeit::DBUpdateSearches($dbh, $subsid, $database, $year, $YTD, @usage)
            }
            if ($action =~ m/Sessions/) {
               EZeit::DBUpdateSessions($dbh, $subsid, $database, $year, $YTD, @usage)
            }
         }
      }
      print "\n";
   } # foreach $d1prefix
} # foreach $year
$dbh->disconnect();

