#!/usr/bin/perl -w
#=========================================================================
#
#    EZB-Reader.pl
#
#    Read in EZB statistics and store them an the database.
#
#    $Id: $
#    Last change: <Tue, 2009/01/06 18:20:48 arwagner ingata>
#    Author     : Alexander Wagner
#    Language   : Perl
#
#-------------------------------------------------------------------------
#
#    Copyright (C) 2008 by Alexander Wagner
#
#    This is free software; you can redistribute it and/or modify it
#    under the terms of the GNU Genereal Public License as published
#    by the Free Software Foundation; either version 2, or (at your
#    option) any later version.
#
#    This program is distributed in the hope that it will be usefull,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#    General Public License for more details.
#
#    You should have recieved a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#=========================================================================

# input is xls, output is mysql, some data comes from ZDB
use DBI;
use IO::Handle;
use EZeit;
*STDOUT->autoflush(1);    # Unbuffered screen IO

#======================================================================

EZeit::ReadConfig();
$dbh = EZeit::ConnectDB();
$zdb = EZeit::ConnectZDB();

print <<EOF
Process indicators:
     .    For each dataset
     c    cumulative counting
     e    Price information ... UPDATE
     E    ..................... ADD
     j    journal inserted     
     m    monthly usage ....... ADD/UPDATE
     N    National Licence
     U    Unresolvable journal
     y    yearly usage ........ UPDATE
     Y    ..................... ADD
     z    ZDB: get ppn
     Z    ZDB: get full record
     :    Processing one ZDB record

      Markers printed: $EZeit::markerstring

EOF
;

print "Input     : $EZeit::inputdir\n\n";

foreach $year (@EZeit::years) {
   foreach $ezbprefix (@EZeit::ezbfiles) {

      my $journalEZBfile = "$ezbprefix$year.csv";

      # Search the counter statistics
      if (-e "$EZeit::inputdir/$journalEZBfile") {
         open (IN, "<$EZeit::inputdir/$journalEZBfile");
      }
      else {
         print "$EZeit::inputdir/$journalEZBfile does not exist!\n";
         print "Exiting...\n\n";
         next;
      }

      print "\n\n"; 
      print "Year      : $year\n"; 
      print "Statistics: $journalEZBfile\n"; 
      print "Database  : $EZeit::dbname\@$EZeit::dbhost\n\n";
      if (not $EZeit::enableZDB) {
         print "--> Not updating from ZDB! <--\n\n";
      }

      %ezbiddone = ();

      # drop 4 lines header
      for (my $i=0; $i < 4; $i++) {
         $line = <IN>;
         if ($i < 3) {
            print "   $line\n";
         }
      }

      while ($line = <IN>) {

         my $journal    = ""; my $publisher  = "";
         my $printissn  = ""; my $onlineissn = "";
         my $YTD        =  0;
         my $ezbid      =  0; my $intezbid   = 0;

         Marker(".");

         $line =~ s/\n//g;

         ($intezbid, $journal, $publisher, $access, 
          $YTD, $onlineissn, $printissn) = split(/\t/, $line);

         $intezbid   = trim($intezbid); 
         $journal    = trim($journal); 
         $publisher  = trim($publisher); 
         $access     = trim($access);
         $YTD        = trim($YTD); 
         $onlineissn = trim($onlineissn); 
         $printissn  = trim($printissn);

         if (($printissn ne "") or ($onlineissn ne "")) {
            $printissn  =~ s/;.*//g;
            $onlineissn =~ s/;.*//g;

            if ($access =~ m/rot/) {
               $access = 0;
            }
            if ($access =~ m/gelb/) {
               $access = 1;
            }
            if ($access =~ m/gruen/) {
               $access = 2;
            }

            $ezbid = EZeit::GetEZBID($dbh, $zdb, $onlineissn, $printissn);

            if ($ezbid > 0) {
               $ezbiddone{$ezbid}++; 
               if ($ezbiddone{$ezbid} > 1) {
                  Marker("c");
               }
               EZeit::UpdateEZBTable($dbh, $intezbid, $ezbid, $access);
               EZeit::UpdateEZBUsage($dbh, $intezbid, $year, $YTD);
            }
         }
         else {
            Marker("U");
         }
      }
   } # foreach $j1prefix
} # foreach $year
$dbh->disconnect();

