#!/usr/bin/perl -w
#=========================================================================
#
#    J1-Reader.pl
#
#    Read in Counter J1 files and store them an the database.
#
#    $Id: $
#    Last change: <Tue, 2009/01/06 18:20:48 arwagner ingata>
#    Author     : Alexander Wagner
#    Language   : Perl
#
#-------------------------------------------------------------------------
#
#    Copyright (C) 2008 by Alexander Wagner
#
#    This is free software; you can redistribute it and/or modify it
#    under the terms of the GNU Genereal Public License as published
#    by the Free Software Foundation; either version 2, or (at your
#    option) any later version.
#
#    This program is distributed in the hope that it will be usefull,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#    General Public License for more details.
#
#    You should have recieved a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#=========================================================================

# input is xls, output is mysql, some data comes from ZDB
use Spreadsheet::ParseExcel;
use DBI;
use IO::Handle;
use EZeit;
*STDOUT->autoflush(1);    # Unbuffered screen IO

#======================================================================
my $Excelj1        = new Spreadsheet::ParseExcel;
my $Sheet          = 0;
my $Bookj1;

EZeit::ReadConfig();
$dbh = EZeit::ConnectDB();
$zdb = EZeit::ConnectZDB();

print <<EOF
Process indicators:
     .    For each dataset
     c    cumulative counting
     e    Price information ... UPDATE
     E    ..................... ADD
     j    journal inserted     
     m    monthly usage ....... ADD/UPDATE
     N    National Licence
     U    Unresolvable journal
     y    yearly usage ........ UPDATE
     Y    ..................... ADD
     z    ZDB: get ppn
     Z    ZDB: get full record
     :    Processing one ZDB record

      Markers printed: $EZeit::markerstring

EOF
;

print "Input     : $EZeit::inputdir\n\n";

foreach $year (@EZeit::years) {
   foreach $j1prefix (@EZeit::j1files) {

      my $journalj1file = "$j1prefix$year.xls";

      # Search the counter statistics
      if (-e "$EZeit::inputdir/$journalj1file") {
         $Bookj1   = $Excelj1->Parse("$EZeit::inputdir/$journalj1file");
      }
      else {
         print "$EZeit::inputdir/$journalj1file does not exist!\n";
         print "Exiting...\n\n";
         next;
      }

      my $Wksj1    = $Bookj1->{Worksheet}[$Sheet];

      print "\n\n"; 
      print "Year      : $year\n"; 
      print "Statistics: $journalj1file, ", $Wksj1->{MaxRow}-6 , " datasets\n"; 
      print "Database  : $EZeit::dbname\@$EZeit::dbhost\n\n";
      if (not $EZeit::enableZDB) {
         print "--> Not updating from ZDB! <--\n\n";
      }

      %ezbiddone = ();

      for(my $Row = 6 ;
      defined $Wksj1->{MaxRow} && $Row <= $Wksj1->{MaxRow};
      $Row++) {
         my $journal   = (); my $publisher = ();
         my $platform  = (); my $printissn = ();
         my $onlineissn= (); my $YTD       = ();
         my $YTDHTML   = (); my $YTDPDF    = ();
         my $monthhead = (); my $ezbid     = 0;

         Marker(".");

         $journal    = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}]->Value;
         $publisher  = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+1]->Value;
         $platform   = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+2]->Value;
         if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+3])) {
            $printissn  = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+3]->Value;
         }
         else {
            $printissn  = "";
         }
         if (defined($Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+4])) {
            $onlineissn = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+4]->Value;
         }
         else {
            $onlineissn = "";
         }
         # Here the monthly values should be read in. It can be between 0
         # and 12 columns for the months.
         # Guess: it starts in january. The headings are of no help.
         for (my $i=5; $i < $Wksj1->{MaxCol}-2; $i++) {
            $usage[$i-5] = $Wksj1->{Cells}[$Row][$Wksj1->{MinCol}+$i]->Value;
         }

         # The yearly data has to be there
         $YTD        = $Wksj1->{Cells}[$Row][$Wksj1->{MaxCol}-2]->Value;
         $YTDHTML    = $Wksj1->{Cells}[$Row][$Wksj1->{MaxCol}-1]->Value;
         $YTDPDF     = $Wksj1->{Cells}[$Row][$Wksj1->{MaxCol}]->Value;

         $ezbid = EZeit::GetEZBID($dbh, $zdb, $onlineissn, $printissn);

         if ($ezbid > 0) {
            $ezbiddone{$ezbid}++; 
            if ($ezbiddone{$ezbid} > 1) {
               Marker("c");
            }
            EZeit::UpdateJournalTable($dbh, 
                     "journal", $journal, $publisher, $onlineissn, 
                     $printissn, $platform, $ezbid);
            EZeit::UpdateMonthUsage($dbh,
                     $ezbid, $platform, $year,
                     $ezbiddone{$ezbid}, @usage);
            EZeit::UpdateYearUsage($dbh,
                     $ezbid, $platform, $year, 
                     $YTDHTML, $YTDPDF, $YTD, $ezbiddone{$ezbid});
         }
         else {
            Marker("U");
            EZeit::UpdateJournalTable($dbh, 
                     "unresolved", $journal, $publisher, 
                     $onlineissn, $printissn, $platform, $ezbid);
         }
      }
   } # foreach $j1prefix
} # foreach $year
$dbh->disconnect();

