#!/usr/bin/perl -w
#=========================================================================
#
#    Statistik
#
#    Procuced the normal statistics out of the database by means of
#    standardised SQL queries.
#
#    $Id: $
#    Last change: <Tue, 2009/01/06 18:20:48 arwagner ingata>
#    Author     : Alexander Wagner
#    Language   : Perl
#
#-------------------------------------------------------------------------
#
#    Copyright (C) 2008 by Alexander Wagner
#
#    This is free software; you can redistribute it and/or modify it
#    under the terms of the GNU Genereal Public License as published
#    by the Free Software Foundation; either version 2, or (at your
#    option) any later version.
#
#    This program is distributed in the hope that it will be usefull,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#    General Public License for more details.
#
#    You should have recieved a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#=========================================================================

# input is xls, output is mysql, some data comes from ZDB
use XML::XPath;
use DBI;
use IO::Handle;
use EZeit;
*STDOUT->autoflush(1);    # Unbuffered screen IO

#======================================================================

sub Output($$$) {

   my ($format, $output, $sth) = @_;

   while (@row = $sth->fetchrow_array) {

      # text output:
      if ($format =~ m/^txt$/) {
         # txt output to screen
         if ($output =~ m/screen$/) {
            foreach $cell (@row) {
               # for braindead dumb excel and silly NLS...
               if (EZeit::IsNumeric($cell)) {
                  $cell =~ s/\./,/g;
               }
               print " $cell |";
            }
            print "\n";
         }
         # if not screen then csv
         else {
            open (OUT, ">>$output");
            foreach $cell (@row) {
               # for braindead dumb excel and silly NLS...
               if (EZeit::IsNumeric($cell)) {
                  $cell =~ s/\./,/g;
               }
               print OUT $cell . "; ";
            }
            print OUT "\n";
            close(OUT);
         }
      }
      elsif ($format =~ m/^xls$/) {
         print "XLS: Not yet implemented.\n"
      }
   }
}


my $xmlfile = "query.xml";
my $xp = XML::XPath->new(filename=>$xmlfile);
my $nodeset = $xp->find('/ezeit');

EZeit::ReadConfig();
$dbh = EZeit::ConnectDB();

$numqueries = $xp->find('count(/ezeit/query)');

for (my $i=1; $i <= $numqueries; $i++) {
   my $name   = $xp->find("/ezeit/query[$i]/name");
   my $output = $xp->find("/ezeit/query[$i]/output");
   my $format = $xp->find("/ezeit/query[$i]/format");
   my $sql    = $xp->find("/ezeit/query[$i]/sql");

   $output = $EZeit::outputdir . "/" . $output;

   print "--------------------------------------------------\n";
   print "[$i/$numqueries] -- As $format to $output\n\n";
   print "$name\n";
   print "--------------------------------------------------\n";

   my $sth = $dbh->prepare($sql);
   $sth->execute;
   Output($format, $output, $sth);
   $sth->finish;
   print "\n\n";
}
$dbh->disconnect();

